"use strict";
/**
 * There are at least 3 different, incompatible interfaces for function call
 * parameters between near-api-js and the near wallet selector. This module
 * provides a standard interface and conversion functions.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardNearFunctionCall = void 0;
const utils_1 = require("@tonic-foundation/utils");
class StandardNearFunctionCall {
    constructor(params) {
        this.params = params;
    }
    /**
     * Return a function call action for @wallet-selector/core.
     */
    toWalletSelectorAction() {
        if (!this.params.gas) {
            throw new Error('Wallet selector action requires .gas parameter to be set');
        }
        const params = {
            args: this.params.args,
            methodName: this.params.methodName,
            gas: this.params.gas.toString(),
            deposit: (this.params.attachedDeposit || utils_1.ZERO).toString(),
        };
        return {
            type: 'FunctionCall',
            params,
        };
    }
    /**
     * Return params for Account.functionCall.
     */
    toAccountFunctionCallParams() {
        return this.params;
    }
}
exports.StandardNearFunctionCall = StandardNearFunctionCall;
